<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities\Query;
use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;


class CustomizacaoTAAservice {

	

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
		$this->connection = $entityManager->getConnection();
    }
    

	public function saveColors($paramsCores){
		$checaCores = $this->entityManager->getConnection()->fetchAll(self::CHECK_CORES, $paramsCores);
		
		if (isset(($checaCores[0][1]))){
			$statement = $this->entityManager->getConnection()->prepare(self::UPDATE_COLORS);
			$statement->bindParam(':CORESJSON', $paramsCores['CORESJSON'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsCores['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
		else {
			$statement = $this->entityManager->getConnection()->prepare(self::INSERT_COLORS);
			$statement->bindParam(':CORESJSON', $paramsCores['CORESJSON'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsCores['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
	
	}
	
	const CHECK_CORES = "
	SELECT 1 FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";

	const UPDATE_COLORS = "
	UPDATE CUSTOMIZACAOTAAMOBILE
		SET CORESJSON = :CORESJSON
		WHERE NRORG = :NRORG
	";
	
	const INSERT_COLORS =
	"INSERT INTO CUSTOMIZACAOTAAMOBILE
	(CORESJSON, NRORG)
	VALUES
	(:CORESJSON, :NRORG)
	";
	
	public function saveImages($paramsImagens){
		$checaImagens = $this->entityManager->getConnection()->fetchAll(self::CHECK_IMAGES, $paramsImagens);
		if(isset($checaImagens[0])){
			$statement = $this->entityManager->getConnection()->prepare(self::UPDATE_IMAGES);
			$statement->bindParam(':JSONB64CUSTOMMEDIA', $paramsImagens['JSONB64CUSTOMMEDIA'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsImagens['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
		
		else{
			$statement = $this->entityManager->getConnection()->prepare(self::INSERT_IMAGES);
			$statement->bindParam(':JSONB64CUSTOMMEDIA', $paramsImagens['JSONB64CUSTOMMEDIA'], \PDO::PARAM_LOB);
			$statement->bindParam(':NRORG',				 $paramsImagens['NRORG'],			  \PDO::PARAM_INT);
			$statement->execute();
		}
		
	
	}
	
	
	const CHECK_IMAGES = "
		SELECT 1 FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";

	const UPDATE_IMAGES = "
		UPDATE CUSTOMIZACAOTAAMOBILE
		SET JSONB64CUSTOMMEDIA = :JSONB64CUSTOMMEDIA
		WHERE NRORG = :NRORG
	";
	
	const INSERT_IMAGES =
	"INSERT INTO CUSTOMIZACAOTAAMOBILE
	(JSONB64CUSTOMMEDIA, NRORG)
	VALUES
	(:JSONB64CUSTOMMEDIA, :NRORG)
	";
	
	public function saveJsonConfig($jsonConfigString, $NRORG) {
	    $checaJsonConfig = $this->entityManager->getConnection()->fetchAll(self::CHECK_JSONCONFIG, ['NRORG' => $NRORG]);
	    if (isset($checaJsonConfig[0])) {
	        $statement = $this->entityManager->getConnection()->prepare(self::UPDATE_JSONCONFIG);
	        $statement->bindParam(':JSONCONFIG', $jsonConfigString, \PDO::PARAM_LOB);
	        $statement->bindParam(':NRORG', $NRORG, \PDO::PARAM_INT);
	         // Executa a declaração
	    	$statement->execute();
	    } else {
	        $statement = $this->entityManager->getConnection()->prepare(self::INSERT_JSONCONFIG);
	        $statement->bindParam(':JSONCONFIG', $jsonConfigString, \PDO::PARAM_LOB);
	        $statement->bindParam(':NRORG', $NRORG, \PDO::PARAM_INT);
	         // Executa a declaração
	    	$statement->execute();
	    }
	}
	
	public function findJsonConfig($nrOrg) {
	    // Prepara a consulta para buscar o JSON config
	    $statement = $this->entityManager->getConnection()->prepare(self::SELECT_JSONCONFIG);
	    $statement->bindParam(':NRORG', $nrOrg, \PDO::PARAM_INT);
	
	    // Executa a consulta
	    $statement->execute();
	
	    // Obtém o resultado
	    $result = $statement->fetch();

		$decode = json_decode($result['JSONCONFIG'], true);
		
		// tratativa de campos
		if (isset($decode['mainLanguage']) && isset($decode['mainLanguage'][0]) && isset($decode['mainLanguage'][0]['name'])) {
			$decode['mainLanguageName'] = $decode['mainLanguage'][0]['name'];
		} else {
			$decode['mainLanguageName'] = "";
		}
		
		if (isset($decode['mainLanguage'])  && isset($decode['mainLanguage'][0]) && isset($decode['mainLanguage'][0]['code'])) {
			$decode['mainLanguageCode'] = $decode['mainLanguage'][0]['code'];
		} else {
			$decode['mainLanguageCode'] = "";
		}
		
		if (isset($decode['modeEntregaDrive']) && !empty($decode['modeEntregaDrive'])) {
		    $decode['entregaDrive'] = true;
		} else if (isset($decode['modeEntrega']) && !empty($decode['modeEntrega'])) {
			$decode['entregaDrive'] = false;
		    $decode['entregaComer'] = in_array("comer", $decode['modeEntrega']);
		    $decode['entregaLevar'] = in_array("levar", $decode['modeEntrega']);
		} else {
			$decode['entregaDrive'] = false;
			$decode['entregaComer'] = false;
			$decode['entregaLevar'] = false;
		}

		
		foreach ($decode as $key => &$value) {
	        if (is_bool($value)) {
	            $value = $value ? "S" : "N";
	        }
		}
		
		$res = array();
		
		$res[] = $decode;

        return $result ? $res : null;
	}
	
	const SELECT_JSONCONFIG = "
	SELECT JSONCONFIG FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";

	
	const CHECK_JSONCONFIG = "
		SELECT JSONCONFIG FROM CUSTOMIZACAOTAAMOBILE WHERE NRORG = :NRORG
	";
	
	const UPDATE_JSONCONFIG = "
		UPDATE CUSTOMIZACAOTAAMOBILE
		    SET JSONCONFIG = :JSONCONFIG
		    WHERE NRORG = :NRORG
	";
	
	const INSERT_JSONCONFIG = "
		INSERT INTO CUSTOMIZACAOTAAMOBILE
			(JSONCONFIG, NRORG)
			VALUES
			(:JSONCONFIG, :NRORG)
	";
}