<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;
use Teknisa\MAN\Services\NovoCodigo;
use Teknisa\MAN\Factories\ImportacaoCatracaFactories;

class ImportacaoCatracaServices {
    
    protected $entityManager;
    protected $importFactories;

	public function __construct(EntityManager $entityManager, ImportacaoCatracaFactories $importFactories) {
        $this->entityManager = $entityManager;
        $this->importFactories = $importFactories;
    }
    
    public function findFilial($conditions){
        $query = $this->entityManager->getConnection()->fetchAll(Utilities\Query::FIND_LOGCATRACA, $conditions);

        if(is_bool($query)){
            $query  = [];
        }else{
            $pos = array();
            $fields = ['IDCATLOGCAT', 'IDCRAHABFILI', 'IDCRALOGCAT', 'IDDATLOGCAT', 'IDDUPLOGCAT', 'IDPROLOGCAT', 'IDSERLOGCAT'];
            
            foreach($query as $index => &$row){
                foreach($row as $field => &$value ){
                    if(in_array($field, $fields)){
                        if ($value === '3'){
                            $value = 'Valor inválido';
                        }else if($value === '2'){
                            $value = 'OK';
                        }else if($value === '1'){
                            $value = 'Não verificado';
                        }
                    }
                }
            }
        }

        return $query;
    }
    
    public function insertDadosCatraca($rows){
        $params = array(); //PARAMETROS
        $IDREGDUPLICADO = array(); // CONTROLE PARA IDREGDUPLICADO DUPLICADO
        $crachaDuplicado = array(); // CONTROLE PARA CRACHÁ DUPLICADO (IDDUPLOGCAT)

        $base64 = explode(",", $rows['ARQEXCEL'][0]['b64File']);
        $data = base64_decode($base64[1]);
        $dataArray = explode(PHP_EOL, $data);

        $NRSEQARQIMP = 0; //SIZE = 10
        $params['NMARQLOGCAT'] = $rows['ARQEXCEL'][0]['name']; //ARQUIVO
        $params['CDOPERADOR'] = $rows['CDOPERADOR']; //NOME OPERADOR
        $params['CDFILIAL'] = $rows['CDFILIAL']; //CÓDIGO FILIAL

        foreach($dataArray as $data => $line){

            if(!empty($line)){
                $info = explode(';', $line);
                ++$NRSEQARQIMP;

                try{
                    $params['NRSEQARQIMP'] = $NRSEQARQIMP;
                    $params['CDCAIXLOGCAT'] = $info[0];
                    $params['NRIDENLOGCAT'] = $info[1];
                    $params['DSDTHRLOGCAT'] = $info[2];
                    $params['NMOPERADOR'] = $info[3];

                    $params['DSOBSLOGCAT'] = $params['CDCAIXLOGCAT']. ' - ' .$params['NRIDENLOGCAT']. ' - ' .$params['NMOPERADOR'];
                }catch (\Exception $e){
                    throw $e;
                }

                // INFOS PARA NOVOCODIGO
                $QTD = 1;
                $CDCONTADOR = 'LOGCATRACA' . $params['CDFILIAL'];
                $params['NRSEQLOGCAT'] = NovoCodigo::geraCodigo($this->entityManager->getConnection(), $CDCONTADOR, $QTD, 10);

                //IDENTIFICADORES
                $params['IDSIMPLOGCAT'] = 'P'; //Identificador da situação do registro de log da importação da catraca - 'P' pendente - 'I' importado
                $params['IDDATLOGCAT'] = '1'; //Identificador da situação do formato da data/hora - '1' Não validado - '2' Ok - '3' Formato de data/hora inválido

                // IDREGDUPLICADO = Verifica se o registro veio duplicado no arquivo (com todos os campos iguais). Se encontrar duplicidade, insere 'S', senão 'N'.
                $chave = $params['CDCAIXLOGCAT'].$params['CDFILIAL'].$params['NRIDENLOGCAT'].$params['NMOPERADOR'];
                if(in_array($chave, $IDREGDUPLICADO)){
                    $params['IDREGDUPLICADO'] = 'S';
                }else{
                    $params['IDREGDUPLICADO'] = 'N';
                    $IDREGDUPLICADO[] = $chave;
                }
                
                // CRACHÁ
                $this->getIDCRALOGCAT($params);
                
                // o campo 'Crachá duplicado' (IDDUPLOGCAT) é '3', quando existem crachás (NRIDENLOGCAT) iguais nos clientes da filial 
                if(in_array($params['NRIDENLOGCAT'], $crachaDuplicado)){
                    $params['IDDUPLOGCAT'] = '3'; // CRACHÁ JÁ EXISTE
                }else{
                    $params['IDDUPLOGCAT'] = '2'; // CRACHÁ OK
                    $crachaDuplicado[] = $params['NRIDENLOGCAT'];
                }
                
                //o campo 'Habilitado filial' (IDCRAHABFILI) é '3' para Crachá não habilitado, se o crachá não estiver habilitado para a filial. E '2' para crachá habilitado
                if($params['IDCRALOGCAT'] == '2'){
                    $params['IDCRAHABFILI'] = '2';
                }else if($params['IDCRALOGCAT'] == '3'){
                    $params['IDCRAHABFILI'] = '3';
                }else{
                    $params['IDCRAHABFILI'] = '1';
                }
                
                // CRATRACA
                $this->getCAIXA($params);
                
                // SERVIÇO
                $this->getIDSERLOGCAT($params);
                
                // PRODUTO
                $this->getIDPROLOGCAT($params);
                
                /*
                    OBSERVAÇÃO:
                        ESSA TELA FOI IMPORTADA DO VND DELPHI. E NA ROTINA DELES, A VERIFICAÇÃO DOS VALORES E A IMPORTAÇÃO DO ARQUIVO ERAM DUAS ROTINAS DIFERENTES.
                        NA IMPORTAÇÃO DO ARQUIVO, TODOS OS CAMPOS ERAM SETADOS PARA O VALOR 2, QUE CORRESPONDE A OK. E O USUÁRIO TINHA A OPÇÃO DE "VALIDAR O ARQUIVO IMPORTADO". NESTA ROTINA DE VALIDAÇÃO, OS CAMPOS ERAM UPTADADOS PARA '3' SE FOSSEM INVÁLIDOS. EU PEGUEI AS DUAS ROTINAS E COLOQUEI LOGO NA IMPORTAÇÃO, ASSIM O ARQUIVO IMPORTADO JÁ VEM VALIDADO.
                        MAS, NO CASO DO CAMPO IDDATLOGCAT, NO UPDATE, ELE UTILIZA UMA FUNÇÃO SQL, CHAMADA DATA_OK. PARA MANTER ESSA FUNÇÃO, EU VOU PASSAR O VALOR DE IDDATLOGCAT COMO 1 NO INSERT E DEPOIS CHAMO O MESMO UPDATE DO DELPHI.
                */
                
                // DEFAULT
                $params['IDDATLOGCAT'] = '1';

                // CHAMADA DO INSERT
                $this->importFactories->insertDadosCatraca($params);
                
                
            }
        }
    }
    
    public function getIDCRALOGCAT(&$params){
        // IDCRALOGCAT -> CRACHÁ
        $param = [
            'NRIDENLOGCAT'  =>  $params['NRIDENLOGCAT'],
            'CDFILIAL'      =>  $params['CDFILIAL']
        ];
        
        $params['IDCRALOGCAT'] = $this->importFactories->getIDCRALOGCAT($param);
    }
    
    public function getCAIXA(&$params){
        //o campo 'Catraca' (IDCATLOGCAT) é '3' Código da catraca inválido, se o caixa for inválido. E '2' se o caixa for válido
        $param = [
            'CDCAIXA'   =>  $params['CDCAIXLOGCAT'],
            'CDFILIAL'  =>  $params['CDFILIAL']
        ];
        
        $params['IDCATLOGCAT'] = $this->importFactories->getCAIXA($param);
    }
    
    public function getIDSERLOGCAT(&$params){
        // o campo 'Serviço' é alterado para '3' Horário sem serviço definido, se o serviço não for encontrado
        $param = [
            'CDCAIXA'           =>  $params['CDCAIXLOGCAT'],
            'CDFILIAL'          =>  $params['CDFILIAL'],
            'DSDTHRLOGCAT'      =>  $params['DSDTHRLOGCAT']
        ];
        
        $params['IDSERLOGCAT'] = $this->importFactories->getIDSERLOGCAT($param);
    }
    
    public function getIDPROLOGCAT(&$params){
       // o campo 'Produto' (IDPROLOGCAT) é '3' Produto Inválido, se o produto não for encontrado
        $param = [
            'CDCAIXA'           =>  $params['CDCAIXLOGCAT'],
            'CDFILIAL'          =>  $params['CDFILIAL'],
            'DSDTHRLOGCAT'      =>  $params['DSDTHRLOGCAT']
        ];
        
        $params['IDPROLOGCAT'] = $this->importFactories->getIDPROLOGCAT($param);
    }
    
    public function setIDDATLOGCAT(&$params){
        $this->importFactories->setIDDATLOGCAT($params);
    }
    
    public function deleteRowLogCatraca($params){
        $this->importFactories->deleteRowLogCatraca($params);
    }
    
}